/**
 * Contains a wrapper for HTTP requests
 *
 * `const { api_connector } = require('nov-nodejs-core-util');`
 * @module api-connector
 */

/**
 * TODO: complete the documentation
 */
exports.api_connector = async (param) => {
  // Set default values
  const contentType = param['contentType'] || 'application/json'
  const apiMethod = param['api_method'] || 'GET'
  const protocol = param['url'].includes('http://') ? require('http') : require('https')
  let payload = null

  // Set the API options
  const options = Object.assign({}, {
    method: apiMethod,
    headers: Object.assign({}, {
      'Content-Type': contentType
    }, param['headers'])
  }, param['custom_options'])

  if (param['payload']) {
    payload = JSON.stringify(param['payload'])
    options.headers['Content-Length'] = payload.length
  }

  const logMessage = `API Method : ${param['api_method']}, URL: ${param['url']}, Payload: ${param['payload']}, Options: ${JSON.stringify(options)}`
  console.info(`StepFunction: ${param['step_function']}, LambdaFunction: ${param['lambda_function']}, Message: ${logMessage}`)

  return new Promise((resolve, reject) => {
    const req = protocol.request(param['url'], options, (res) => {
      const body = []
      res.on('data', (chunk) => body.push(chunk))
      res.on('end', () => {
        // eslint-disable-next-line eqeqeq
        if (res.statusCode != '200' || res.statusCode > '299') {
          // reject (new Error(`HTTP status code: ${res.statusCode}, response: ${body}`))
          console.log(`HTTP status code: ${res.statusCode}, response: ${body}`)
          resolve(res.statusCode)
        }
        const resString = Buffer.concat(body).toString()
        if (resString.length > 0) {
          resolve(resString)
        } else {
          resolve(false)
        }
      })
    })

    req.on('error', (err) => {
      reject(err)
    })

    req.on('timeout', () => {
      req.destroy()
      reject(new Error('Request time out', req))
    })
    if (param['payload']) {
      req.write(payload)
    }
    req.end()
  })
}
