/* eslint-disable no-undef */
const { api_connector } = require('./index')
const msw = require('msw')
const node = require('msw/node')

const server = node.setupServer(
  msw.rest.get('http://localhost:3000/get/success', (req, res, ctx) => {
    return res(ctx.json({ result: 'ok' }))
  }),
  msw.rest.get('http://localhost:3000/get/403', (req, res, ctx) => {
    return res(ctx.status(403))
  }),
  msw.rest.post('http://localhost:3000/post/200', async (req, res, ctx) => {
    const response = await req.json()
    return res(ctx.json(response))
  })
)

beforeAll(() => server.listen())
afterEach(() => server.resetHandlers())
afterAll(() => server.close())

describe('api_connector method', () => {
  test('response of a successful get request', async () => {
    const response = await api_connector({
      url: 'http://localhost:3000/get/success',
      api_method: 'GET'
    })

    expect(JSON.parse(response).result).toBe('ok')
  })

  test('response of a status code 403 get request', async () => {
    const response = await api_connector({
      url: 'http://localhost:3000/get/403',
      api_method: 'GET'
    })

    expect(response).toBe(403)
  })

  test('response of a successful post request', async () => {
    const response = await api_connector({
      url: 'http://localhost:3000/post/200',
      api_method: 'POST',
      payload: { test: 123 }
    })

    expect(JSON.parse(response).test).toBe(123)
  })
})
