/* eslint-disable quotes */
/* eslint-disable no-undef */
const util = require('./index')

describe('to_base64 method', () => {
  test('string to base64 string', () => {
    expect(util.to_base64('test')).toBe('dGVzdA==')
  })

  test('number to base64 string', () => {
    expect(util.to_base64(69)).toBe('Njk=')
  })

  test('object to base64 string', () => {
    expect(util.to_base64({ test: 1 })).toBe('eyJ0ZXN0IjoxfQ==')
  })

  test('undefined to base64 string to be empty string', () => {
    expect(util.to_base64()).toBe('')
  })
})

describe('json_to_xml method', () => {
  test('valid js object to be converted to xml with root element passed', () => {
    expect(util.json_to_xml({ test: 1 }, 'x')).toBe("<?xml version='1.0'?>\n" +
      "<x>\n" +
      "    <test>1</test>\n" +
      "</x>")
  })

  test('valid js object to be converted to xml without root element passed', () => {
    expect(util.json_to_xml({ test: 1 })).toBe("<?xml version='1.0'?>\n" +
        "<root>\n" +
        "    <test>1</test>\n" +
        "</root>")
  })

  test('valid json string to be converted to xml', () => {
    expect(util.json_to_xml("{ \"test\" : 1 }")).toBe("<?xml version='1.0'?>\n" +
        "<root>\n" +
        "    <test>1</test>\n" +
        "</root>")
  })

  test('invalid json to fail with exception', () => {
    const t = () => {
      util.json_to_xml('{ = : 1 }')
    }
    expect(t).toThrow()
  })
})

describe('xml_to_json method', () => {
  test('valid xml to be converted to json', () => {
    expect(util.xml_to_json("<x>\n" +
      "    <test>1</test>\n" +
      "</x>")).toBe("{\"x\":{\"test\":{\"_text\":\"1\"}}}")
  })

  test('invalid xml to fail with exception', () => {
    const t = () => {
      util.xml_to_json("<x>\n" +
          "    <test>1</test>\n" +
            "</p>")
    }
    expect(t).toThrow()
  })
})
